#!/usr/bin/python3
# -*- coding: utf-8 -*-
 
import sys
import os
import re
import json
 
# Определяем тип тестирующей системы
# В отладочных целях можно заменить эти переменные на константы True/False
POLYGON = ("polygon" in os.environ.get("APPDATA", "0").lower()) or ("codeforces" in os.environ.get("APPDATA", "0").lower())
EJUDGE = "EJUDGE" in os.environ
SILVER = "SILVERTESTS_VERSION" in os.environ
SIRIUS = not(POLYGON or EJUDGE or SILVER)
 
# Коды возврата для передачи в функцию quit
OK = 0
WA = 1
PT = 1
PE = 2
CF = 3
 
# Класс для работы с ответом участника в тестирующей системе Сириуса
class AnswerSMT():
    def __init__(self, userAnswer=None, score=0, maxScore=100):
        '''считывание ответа'''
        if userAnswer is None:
            self.userAnswer = json.loads("".join(sys.stdin.readlines()))['solution']
        else:
            self.userAnswer = json.loads(userAnswer)
        
        
        '''считаем количество элементов ввода и делаем список ответов по элементам ввода'''
        if type(self.userAnswer) is dict:
            self.elements = 1
            if type(self.userAnswer['solution']) is dict:
                self.userAnswer = [[self.userAnswer['solution']['message']]]
            elif type(self.userAnswer['solution']) is int:
                self.userAnswer = [[self.userAnswer['solution']]]
            else:
                self.userAnswer = [self.userAnswer['solution']]
        else: 
            self.elements = len(self.userAnswer)
            a = []
            for i in range(0, self.elements):
                if type(self.userAnswer[i]['solution']) is int:
                    a.append([self.userAnswer[i]['solution']])
                else:
                    a.append(self.userAnswer[i]['solution'])
            self.userAnswer = a
        
        '''считаем, сколько полей ввода для каждого элемента ввода'''
        self.userAnswerLength = []
        for i in range(0, self.elements):
            if type(self.userAnswer[i]) is list:
                self.userAnswerLength.append(len(self.userAnswer[i]))
            elif self.userAnswer[i] != '':
                self.userAnswerLength.append(1)
            else:
                self.userAnswerLength.append(0)
        
        self.comment = ''
        self.score = score
        self.maxScore = maxScore
        self.verdict = 'WA'
          
    def answer(self, element=0, field=0):
        '''Возвращает ответ участника из элмента ввода с номером element.
        Если в элементе ввода несколько полей ввода, то можно указать номер поля ввода'''
        if element >= self.elements:
            return None
        else:
            a = self.userAnswer[element]
        
        if a is None:
            return None
        if field >= len(a):
            return None
        else: 
            return None if a[field] is None else str(a[field])
    
    def fields_in_element(self, element=0):
        '''Возвращает информацию о количестве полей ввода в элементе ввода'''
        if len(self.userAnswerLength) <= element: 
            return 0
        else:
            return self.userAnswerLength[element]
    
    def print_answer(self):
        '''посмотреть всё содержимое для отладки'''
        print("user answer:")
        print(self.userAnswer)
        print("number of elements")
        print(self.elements)
        print('length of elements')
        print(self.userAnswerLength)
    
    def quit(self, comment=None, score=None, maxScore=None, verdict=None):
        if not comment is None:
            self.comment = comment
        
        if not score is None:
            self.score = score
        
        if not maxScore is None:
            self.maxScore = maxScore
            
        if not verdict is None:
            self.verdict = verdict
            
        print(json.dumps({"maxScore":self.maxScore,
                          "score":self.score,
                          "comment":self.comment,
                          "verdict":self.verdict}))
        sys.exit(0)
 
 
def quit(status, log="", score=0):
    if SIRIUS:
        if status in [OK, WA] and 0 < score < 100:
            status = PT
        comment = log.replace("\n", "\n\n") # Дублируем концы строк для разметки
        sirius_ans_obj.quit(verdict=status, comment=comment, score=score)
        return
    
    if POLYGON: # Нужно в Polygon, т.к. там Windows
        sys.stdout.reconfigure(encoding='utf-8')
        sys.stderr.reconfigure(encoding='utf-8')
 
    # Выводим набранные баллы
    if status in [OK, WA]:
        if POLYGON:
            sys.stderr.write("points " + str(score) + "\n")
            status = 7 # Код возврата полигона, сообщающий о наличии баллов
        elif EJUDGE or SILVER:
            sys.stdout.write(str(score) + "\n")
    
    # Выводим протокол проверки
    sys.stderr.write(log)
    
    # Возвращаем код возврата
    sys.exit(status)
 
 
def init():
    global OK, WA, PE, CF, PT
    global sirius_ans_obj
    if SIRIUS:
        PE = "PE"
        WA = "WA"
        OK = "OK"
        СF = "CF"
        PT = "PT"
        # При создании объекта можно в конструктор в целях отладки передать строку с JSON, тогда ответ будет считан с этого JSON, иначе из stdin
        sirius_ans_obj = AnswerSMT()
 
 
init()
 
########################################################################################
# Код дальше можно править
# 
# Код этой функции надо исправить так, чтобы она возвращала ответ, полученный из JSON в Сириусе
# или полученный из файла в тестирующих системах Ejudge или Polygon
# Формат возвращаемого значения - произвольный, например, одна строка или список строк
# При необходимости можно прямо в этом коде делать quit(PE, ...)
#
# В тестирующей системе Сириуса:
# Задание состоит из "элементов" (разделов"), внутри раздела могут быть поля ввода.
# Например, задание вида "Дайте ответ для а) N = 10 б) N = 20, в) N = 30" - это три раздела, они будут визуально отделены.
# А задание вида "Напишите в ответе номера объектов, которые вы выбрали, добавляя поля по необходимости" - это один раздел с несколькими полями ввода
# При считывании данных из тестирующей системы Сириуса нужно использовать объект sirius_ans_obj
# со следующим интерфейсом.
# sirius_ans_obj.elements - количество "элементов" в ответе.
# sirius_ans_obj.fields_in_element(element=0) - возвращает количество полей ввода в элементе номер element, нумерация с нуля
# sirius_ans_obj.answer(element=0, field=0) - возвращает значение поля ввода номер field из элемента номер element, нумерация с нуля
########################################################################################
 
def get_answer():
    ans = []
    if SIRIUS:
        for i in range(sirius_ans_obj.elements):
            elem = sirius_ans_obj.answer(element=i)
            # Если ответ в Сириусе состоит из нескольких полей, то там может оказаться None. Необходимо это учесть.
            if elem is None:
                elem = ""
            ans.append(elem.strip())
    elif POLYGON or SILVER:
        if POLYGON:
            fin = open(sys.argv[2], "r", encoding="utf8")
        elif SILVER:
            fin = sys.stdin
        for elem in fin:
            ans.append(elem.strip())
    return ans
 
ans = get_answer()

if len(ans) == 0:
    quit(PE, "Ответ пустой")

ans = str(ans[0]).strip()

if len(ans) == 0:
    quit(PE, "Ответ пустой")
 
ans = ans.replace("W", "w")
ans = ans.replace("H", "h")
ans = ans.replace("Ц", "w") # русская
ans = ans.replace("Р", "h") # русская
ans = ans.replace("ц", "h") # русская
ans = ans.replace("р", "w") # русская
ans = ans.replace("a", "w") # латинская a вместо w
ans = ans.replace("A", "w") # латинская A вместо w
ans = ans.replace("b", "h") # латинская b вместо h
ans = ans.replace("B", "h") # латинская B вместо h
ans = ans.replace(chr(215), "*")  # неправильное умножение
ans = ans.replace(chr(8727), "*") # неправильное умножение
ans = ans.replace(chr(8212), "-") # неправильный минус
ans = ans.replace(chr(8722), "-") # неправильный минус

 
for char in ans:
    if char not in " wh+-*0123456789()":
        quit(PE, "Ответ содержит недопустимый символ: ''" + char + "''" + "\n")
if "**" in ans:
    quit(PE, "В ответе не может использоваться ''**''" + "\n")
if "//" in ans:
    quit(PE, "В ответе не может использоваться ''//''" + "\n")
if "/" in ans:
    quit(PE, "В ответе не может использоваться ''/''" + "\n")
if "\n" in ans:
    quit(PE, "Ответ должен быть в одной строке" + "\n")
ALL_PASSED = True
 
ANSWERS = dict()

for d in range(-100, 101):
    s = f"4*w + 4*h {d:+}"
    if d == 20:
        ANSWERS[s] = 100
    elif d == 4:  # Забыл при подсчёте периметра боковушки
        ANSWERS[s] = 40
    elif d == 16: # Ошибка на 1 при подсчёте перпендикулярных линий
        ANSWERS[s] = 40
    elif d % 4 == 0:
        ANSWERS[s] = 35
    elif d % 2 == 0:
        ANSWERS[s] = 30
    else:
        ANSWERS[s] = 25

ANSWERS["2*(w+h+8)"] = 15  # Только периметр посчитал


EPS = 1e-6
try:
    for w in range(1, 21, 2):
        for h in range(1, 21, 2):
            for sample in list(ANSWERS.keys()):
                if abs(eval(ans) - eval(sample)) > EPS:
                    del ANSWERS[sample]
except ZeroDivisionError as E:
    quit(WA, "При вычислении выражения возникло деление на ноль.\n", 0)
except Exception as E:
    quit(PE, "Некорректное арифметическое выражение.\n")
 
if len(ANSWERS) > 1:
    quit(CF, "Два подходящих варианта ответа в критериях оценивания.\n" + str(ANSWERS), 0)
 
if len(ANSWERS) == 0:
    quit(WA, "Это неправильный ответ\n", 0)
 
for sample in ANSWERS:
    if ANSWERS[sample] == 100:
        quit(OK, "Это правильный ответ\n", ANSWERS[sample])
    else:
        quit(WA, "Ответ эквивалентен выражению " + sample + ".\nЭто неправильный ответ.\n", ANSWERS[sample])
