#!/usr/bin/python3
# -*- coding: utf-8 -*-

import sys
import os
import re
import json

# Определяем тип тестирующей системы
# В отладочных целях можно заменить эти переменные на константы True/False
POLYGON = ("polygon" in os.environ.get("APPDATA", "0").lower()) or (
        "codeforces" in os.environ.get("APPDATA", "0").lower())
EJUDGE = "EJUDGE" in os.environ
SILVER = "SILVERTESTS_VERSION" in os.environ
SIRIUS = not (POLYGON or EJUDGE or SILVER)

# Коды возврата для передачи в функцию quit
OK = 0
WA = 1
PT = 1
PE = 2
CF = 3


# Класс для работы с ответом участника в тестирующей системе Сириуса
class AnswerSMT():
    def __init__(self, userAnswer=None, score=0, maxScore=100):
        '''считывание ответа'''
        if userAnswer is None:
            self.userAnswer = json.loads("".join(sys.stdin.readlines()))['solution']
        else:
            self.userAnswer = json.loads(userAnswer)

        '''считаем количество элементов ввода и делаем список ответов по элементам ввода'''
        if type(self.userAnswer) is dict:
            self.elements = 1
            if type(self.userAnswer['solution']) is dict:
                self.userAnswer = [[self.userAnswer['solution']['message']]]
            elif type(self.userAnswer['solution']) is int:
                self.userAnswer = [[self.userAnswer['solution']]]
            else:
                self.userAnswer = [self.userAnswer['solution']]
        else:
            self.elements = len(self.userAnswer)
            a = []
            for i in range(0, self.elements):
                if type(self.userAnswer[i]['solution']) is int:
                    a.append([self.userAnswer[i]['solution']])
                else:
                    a.append(self.userAnswer[i]['solution'])
            self.userAnswer = a

        '''считаем, сколько полей ввода для каждого элемента ввода'''
        self.userAnswerLength = []
        for i in range(0, self.elements):
            if type(self.userAnswer[i]) is list:
                self.userAnswerLength.append(len(self.userAnswer[i]))
            elif self.userAnswer[i] != '':
                self.userAnswerLength.append(1)
            else:
                self.userAnswerLength.append(0)

        self.comment = ''
        self.score = score
        self.maxScore = maxScore
        self.verdict = 'WA'

    def answer(self, element=0, field=0):
        '''Возвращает ответ участника из элмента ввода с номером element.
        Если в элементе ввода несколько полей ввода, то можно указать номер поля ввода'''
        if element >= self.elements:
            return None
        else:
            a = self.userAnswer[element]

        if a is None:
            return None
        if field >= len(a):
            return None
        else:
            return None if a[field] is None else str(a[field])

    def fields_in_element(self, element=0):
        '''Возвращает информацию о количестве полей ввода в элементе ввода'''
        if len(self.userAnswerLength) <= element:
            return 0
        else:
            return self.userAnswerLength[element]

    def print_answer(self):
        '''посмотреть всё содержимое для отладки'''
        print("user answer:")
        print(self.userAnswer)
        print("number of elements")
        print(self.elements)
        print('length of elements')
        print(self.userAnswerLength)

    def quit(self, comment=None, score=None, maxScore=None, verdict=None):
        if not comment is None:
            self.comment = comment

        if not score is None:
            self.score = score

        if not maxScore is None:
            self.maxScore = maxScore

        if not verdict is None:
            self.verdict = verdict

        print(json.dumps({"maxScore": self.maxScore,
                          "score": self.score,
                          "comment": self.comment,
                          "verdict": self.verdict}))
        sys.exit(0)


def quit(status, log="", score=0):
    if SIRIUS:
        if status in [OK, WA] and 0 < score < 100:
            status = PT
        comment = log.replace("\n", "\n\n")  # Дублируем концы строк для разметки
        sirius_ans_obj.quit(verdict=status, comment=comment, score=score)
        return

    if POLYGON:  # Нужно в Polygon, т.к. там Windows
        sys.stdout.reconfigure(encoding='utf-8')
        sys.stderr.reconfigure(encoding='utf-8')

    # Выводим набранные баллы
    if status in [OK, WA]:
        if POLYGON:
            sys.stderr.write("points " + str(score) + "\n")
            status = 7  # Код возврата полигона, сообщающий о наличии баллов
        elif EJUDGE or SILVER:
            sys.stdout.write(str(score) + "\n")

    # Выводим протокол проверки
    sys.stderr.write(log)

    # Возвращаем код возврата
    sys.exit(status)


def init():
    global OK, WA, PE, CF, PT
    global sirius_ans_obj
    if SIRIUS:
        PE = "PE"
        WA = "WA"
        OK = "OK"
        СF = "CF"
        PT = "PT"
        # При создании объекта можно в конструктор в целях отладки передать строку с JSON, тогда ответ будет считан с этого JSON, иначе из stdin
        sirius_ans_obj = AnswerSMT()


init()


########################################################################################
# Код дальше можно править
#
# Код этой функции надо исправить так, чтобы она возвращала ответ, полученный из JSON в Сириусе
# или полученный из файла в тестирующих системах Ejudge или Polygon
# Формат возвращаемого значения - произвольный, например, одна строка или список строк
# При необходимости можно прямо в этом коде делать quit(PE, ...)
#
# В тестирующей системе Сириуса:
# Задание состоит из "элементов" (разделов"), внутри раздела могут быть поля ввода.
# Например, задание вида "Дайте ответ для а) N = 10 б) N = 20, в) N = 30" - это три раздела, они будут визуально отделены.
# А задание вида "Напишите в ответе номера объектов, которые вы выбрали, добавляя поля по необходимости" - это один раздел с несколькими полями ввода
# При считывании данных из тестирующей системы Сириуса нужно использовать объект sirius_ans_obj
# со следующим интерфейсом.
# sirius_ans_obj.elements - количество "элементов" в ответе.
# sirius_ans_obj.fields_in_element(element=0) - возвращает количество полей ввода в элементе номер element, нумерация с нуля
# sirius_ans_obj.answer(element=0, field=0) - возвращает значение поля ввода номер field из элемента номер element, нумерация с нуля
########################################################################################

def get_answer():
    ans = []
    if SIRIUS:
        for i in range(sirius_ans_obj.elements):
            elem = sirius_ans_obj.answer(element=i)
            # Если ответ в Сириусе состоит из нескольких полей, то там может оказаться None. Необходимо это учесть.
            if elem is None:
                elem = ""
            ans.append(elem.strip())
    elif POLYGON or SILVER:
        if POLYGON:
            fin = open(sys.argv[2], "r", encoding="utf8")
        elif SILVER:
            fin = sys.stdin
        N_ans = 4
        for elem in fin:
            if elem.strip():
                ans.append(elem.strip())
        while len(ans) < N_ans:
            ans.append("")
    return ans


ans = get_answer()

if len(ans) < 4:
    quit(CF, "Меньше 4 строк в ответе")

if len(ans) > 4:
    quit(PE, "В ответе должно быть ровно 4 строки")


alph = set(list("LRUD"))
lens = [3,5,7,9]

def coord_ok(i, j):
    return 0 <= i < 7 and 0 <= j < 9

ANS = [
    "DRU",
    "LLLUU",
    "UULLLDD",
    "DRRDRRRDD"
]

field = [[3, 4, 1, 3, -99, 3, 2, 1, 6],
         [3, -99, 1, 2, 1, 2, 2, 1, 1],
         [4, 3, 1, 0, 3, -99, -99, 4, 3],
         [1, 1, -99, 5, 1, 2, 2, 2, 3],
         [2, 3, -99, 1, -99, 2, 2, 4, 1],
         [4, 1, 4, 1, -99, 3, 3, -99, 1],
         [2, 3, 2, 2, 1, 4, 2, -99, 9]]

points = 0

dirs = {'U': [-1,0],
        'D': [1, 0],
        'L': [0, -1],
        'R': [0, 1]
        }
errors = []

i = 0
while i < len(ans):
    ans[i] = ans[i].strip().upper()
    ans[i] = ans[i].replace(" ", "")
    ans[i] = ans[i].replace(",", "")
    ans[i] = ans[i].replace(";", "")
    ans[i] = ans[i].replace("-", "")
    i += 1

for i in range(min(4,len(ans))):
    y, x = 2, 3
    jury_ans = 0
    for c in ANS[i]:
        y+=dirs[c][0]
        x+=dirs[c][1]
        jury_ans += field[y][x]
    y, x = 2, 3
    user_ans = 0
    if len(ANS[i])!=len(ans[i]):
        errors.append(f"{i+1}-я строка содержит неверное количество символов. Должно быть {lens[i]} { 'символа.' if lens[i]==3 else 'символов.'}")
        continue
    if len(set(list(ans[i])) - alph):
        errors.append(f"{i+1}-я строка содержит символ, который отличается от символов из набора L, R, D и U.")
        continue
    cfield = [row[:] for row in field]
    for c in ans[i]:
        y+=dirs[c][0]
        x+=dirs[c][1]
        if coord_ok(y,x) and cfield[y][x] == -99:
            errors.append(f"Робот наехал на препятствие в ответе {i+1}.")
            #user_ans=0
            break
        elif coord_ok(y,x):
            user_ans += cfield[y][x]
            cfield[y][x] = 0
        else:
            errors.append(f"Робот вышел за пределы помещения в ответе {i+1}.")
            #user_ans=0
            break
        
    if jury_ans==user_ans:
        points += 25
    elif jury_ans-user_ans==1:
        points += 15
    elif jury_ans-user_ans<=5:
        points += max(0, (6 - (jury_ans-user_ans))*3)

if points == 100:
    quit(OK, "Это правильный ответ.", score=points)
else:
    quit(OK, "Это неверный или не самый лучший ответ.\n" if len(errors)==0 else '\n'.join(errors), score=points)
