#!/usr/bin/python3
# -*- coding: utf-8 -*-
 
import sys
import os
import re
import json
 
# Определяем тип тестирующей системы
# В отладочных целях можно заменить эти переменные на константы True/False
POLYGON = ("polygon" in os.environ.get("APPDATA", "0").lower()) or ("codeforces" in os.environ.get("APPDATA", "0").lower())
EJUDGE = "EJUDGE" in os.environ
SILVER = "SILVERTESTS_VERSION" in os.environ
SIRIUS = not(POLYGON or EJUDGE or SILVER)
 
# Коды возврата для передачи в функцию quit
OK = 0
WA = 1
PT = 1
PE = 2
CF = 3
 
# Класс для работы с ответом участника в тестирующей системе Сириуса
class AnswerSMT():
    def __init__(self, userAnswer=None, score=0, maxScore=100):
        '''считывание ответа'''
        if userAnswer is None:
            self.userAnswer = json.loads("".join(sys.stdin.readlines()))['solution']
        else:
            self.userAnswer = json.loads(userAnswer)
        
        
        '''считаем количество элементов ввода и делаем список ответов по элементам ввода'''
        if type(self.userAnswer) is dict:
            self.elements = 1
            if type(self.userAnswer['solution']) is dict:
                self.userAnswer = [[self.userAnswer['solution']['message']]]
            elif type(self.userAnswer['solution']) is int:
                self.userAnswer = [[self.userAnswer['solution']]]
            else:
                self.userAnswer = [self.userAnswer['solution']]
        else: 
            self.elements = len(self.userAnswer)
            a = []
            for i in range(0, self.elements):
                if type(self.userAnswer[i]['solution']) is int:
                    a.append([self.userAnswer[i]['solution']])
                else:
                    a.append(self.userAnswer[i]['solution'])
            self.userAnswer = a
        
        '''считаем, сколько полей ввода для каждого элемента ввода'''
        self.userAnswerLength = []
        for i in range(0, self.elements):
            if type(self.userAnswer[i]) is list:
                self.userAnswerLength.append(len(self.userAnswer[i]))
            elif self.userAnswer[i] != '':
                self.userAnswerLength.append(1)
            else:
                self.userAnswerLength.append(0)
        
        self.comment = ''
        self.score = score
        self.maxScore = maxScore
        self.verdict = 'WA'
          
    def answer(self, element=0, field=0):
        '''Возвращает ответ участника из элмента ввода с номером element.
        Если в элементе ввода несколько полей ввода, то можно указать номер поля ввода'''
        if element >= self.elements:
            return None
        else:
            a = self.userAnswer[element]
        
        if a is None:
            return None
        if field >= len(a):
            return None
        else: 
            return None if a[field] is None else str(a[field])
    
    def fields_in_element(self, element=0):
        '''Возвращает информацию о количестве полей ввода в элементе ввода'''
        if len(self.userAnswerLength) <= element: 
            return 0
        else:
            return self.userAnswerLength[element]
    
    def print_answer(self):
        '''посмотреть всё содержимое для отладки'''
        print("user answer:")
        print(self.userAnswer)
        print("number of elements")
        print(self.elements)
        print('length of elements')
        print(self.userAnswerLength)
    
    def quit(self, comment=None, score=None, maxScore=None, verdict=None):
        if not comment is None:
            self.comment = comment
        
        if not score is None:
            self.score = score
        
        if not maxScore is None:
            self.maxScore = maxScore
            
        if not verdict is None:
            self.verdict = verdict
            
        print(json.dumps({"maxScore":self.maxScore,
                          "score":self.score,
                          "comment":self.comment,
                          "verdict":self.verdict}))
        sys.exit(0)
 
 
def quit(status, log="", score=0):
    if SIRIUS:
        if status in [OK, WA] and 0 < score < 100:
            status = PT
        comment = log.replace("\n", "\n\n") # Дублируем концы строк для разметки
        sirius_ans_obj.quit(verdict=status, comment=comment, score=score)
        return
    
    if POLYGON: # Нужно в Polygon, т.к. там Windows
        sys.stdout.reconfigure(encoding='utf-8')
        sys.stderr.reconfigure(encoding='utf-8')
 
    # Выводим набранные баллы
    if status in [OK, WA]:
        if POLYGON:
            sys.stderr.write("points " + str(score) + "\n")
            status = 7 # Код возврата полигона, сообщающий о наличии баллов
        elif EJUDGE or SILVER:
            sys.stdout.write(str(score) + "\n")
    
    # Выводим протокол проверки
    sys.stderr.write(log)
    
    # Возвращаем код возврата
    sys.exit(status)
 
 
def init():
    global OK, WA, PE, CF, PT
    global sirius_ans_obj
    if SIRIUS:
        PE = "PE"
        WA = "WA"
        OK = "OK"
        СF = "CF"
        PT = "PT"
        # При создании объекта можно в конструктор в целях отладки передать строку с JSON, тогда ответ будет считан с этого JSON, иначе из stdin
        sirius_ans_obj = AnswerSMT()
 
 
init() 

########################################################################################
# Код дальше можно править
# 
# Код этой функции надо исправить так, чтобы она возвращала ответ, полученный из JSON в Сириусе
# или полученный из файла в тестирующих системах Ejudge или Polygon
# Формат возвращаемого значения - произвольный, например, одна строка или список строк
# При необходимости можно прямо в этом коде делать quit(PE, ...)
#
# В тестирующей системе Сириуса:
# Задание состоит из "элементов" (разделов"), внутри раздела могут быть поля ввода.
# Например, задание вида "Дайте ответ для а) N = 10 б) N = 20, в) N = 30" - это три раздела, они будут визуально отделены.
# А задание вида "Напишите в ответе номера объектов, которые вы выбрали, добавляя поля по необходимости" - это один раздел с несколькими полями ввода
# При считывании данных из тестирующей системы Сириуса нужно использовать объект sirius_ans_obj
# со следующим интерфейсом.
# sirius_ans_obj.elements - количество "элементов" в ответе.
# sirius_ans_obj.fields_in_element(element=0) - возвращает количество полей ввода в элементе номер element, нумерация с нуля
# sirius_ans_obj.answer(element=0, field=0) - возвращает значение поля ввода номер field из элемента номер element, нумерация с нуля
########################################################################################

DATA = """
59
61
61
61
62
62
63
63
63
63
63
63
64
64
64
64
64
64
64
64
64
64
64
65
65
65
65
65
65
65
65
65
65
65
65
65
65
66
66
66
66
66
66
66
66
66
66
66
66
66
66
66
66
66
66
66
66
66
67
67
67
67
67
67
67
67
67
67
67
67
67
67
67
67
67
67
67
67
67
67
67
67
67
67
67
67
67
68
68
68
68
68
68
68
68
68
68
68
68
68
68
68
68
68
68
68
68
68
68
68
68
68
68
68
68
68
68
68
68
68
68
69
69
69
69
69
69
69
69
69
69
69
69
69
69
69
69
69
69
69
69
69
69
69
69
69
69
69
69
69
69
69
69
69
69
69
69
69
69
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
70
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
71
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
72
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
73
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
74
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
75
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
76
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
77
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
78
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
79
80
80
80
80
80
80
80
80
80
80
80
80
80
80
80
80
80
80
80
80
80
80
80
80
80
80
80
80
80
80
80
80
80
80
80
80
80
80
80
80
80
80
81
81
81
81
81
81
81
81
81
81
81
81
81
81
81
81
81
81
81
81
81
81
81
81
81
81
81
81
81
81
81
82
82
82
82
82
82
82
82
82
82
82
82
82
82
82
82
82
82
82
82
82
82
82
82
82
82
82
82
82
82
82
82
82
83
83
83
83
83
83
83
83
83
83
83
83
83
83
83
83
83
83
83
83
83
83
83
83
83
83
83
84
84
84
84
84
84
84
84
84
84
84
84
84
84
84
84
84
84
84
84
84
84
85
85
85
85
85
85
85
85
85
85
85
85
86
86
86
86
86
86
86
86
86
86
86
86
86
86
86
87
87
87
88
88
88
88
88
89
89
89
90
90
90
90
91
93
"""

DATA = list(map(int, DATA.split()))

# Код дальше можно править

N_ans = 3

# Код этой функции надо исправить так, чтобы она возвращала ответ, полученный из JSON в Сириусе
# или полученный из файла в тестирующих системах Ejudge или Polygon
# Формат возвращаемого значения - произвольный, например, одна строка или список строк
# При необходимости можно прямо в этом коде делать quit(PE, ...)
def get_answer():
    ans = []
    if SIRIUS:
        for i in range(N_ans):
            elem = sirius_ans_obj.answer(field=i)
            if elem is None:
                elem = ""
            ans.append(elem.strip())
    elif POLYGON or SILVER:
        if POLYGON:
            fin = open(sys.argv[2], "r", encoding="utf8")
        elif SILVER:
            fin = sys.stdin
        ans = fin.read().replace(",", " ").replace(";", " ").split()
    return ans

ans = get_answer()

for i in range(len(ans)):
    ans[i] = ans[i].strip()
    if not ans[i].isdigit():
        quit(PE, "В ответе должны быть три натуральных числа\n")
    ans[i] = int(ans[i])

if len(ans) != N_ans:
    quit(PE, "В ответе должны быть три натуральных числа\n")

if sum(ans) != 1000:
    quit(PE, f"Сумма чисел в ответе должна быть равна 1000, сумма чисел в вашем ответе равна {sum(ans)}\n")

a, b, c = ans

if a == 0 or b == 0 or c == 0:
    quit(PE, "В ответе есть пустая весовая категория\n")

if DATA[a-1] == DATA[a]:
    quit(WA, f"Нарушены спортивные правила, в лёгкой и средней категориях есть спортсмены с равным весом {DATA[a]}")

if DATA[a+b-1] == DATA[a+b]:
    quit(WA, f"Нарушены спортивные правила, в средней и тяжёлой категориях есть спортсмены с равным весом {DATA[a+b]}")

s1 = sum(DATA[:a])
s2 = sum(DATA[a:a+b])
s3 = sum(DATA[a+b:a+b+c])

d = max(s1, s2, s3)

D = [26261, 27730, 30551, 30758, 30777, 31013, 32910, 33616, 34137, 34174, 34918, 35303, 35449, 36238, 36415, 36610, 36648, 36937, 37641, 38019, 38143, 38263, 38326, 38385, 38550, 38698, 38809, 39208, 39283, 39354, 40201, 40493, 40573, 40834, 41274, 41320, 41541, 41595, 41879, 41901, 41992, 42085, 42789, 42988, 43443, 43493, 43561, 43632, 43871, 43995, 44026, 44106, 44178, 44237, 44463, 45575, 45610, 45753, 46014, 46072, 46267, 46454, 46721, 46961, 47081, 47172, 47265, 47466, 47871, 47886, 47922, 48115, 48575, 48778, 48953, 49077, 49135, 49260, 49319, 49865, 49977, 50425, 50508, 50686, 51019, 51126, 51246, 51251, 51393, 51753, 51844, 51937, 52161, 52683, 52820, 52865, 52867, 53243, 53367, 53550, 53609, 53757, 53868, 53887, 54763, 54924, 55177, 55438, 55878, 56145, 56149, 56180, 56379, 56463, 56505, 56596, 56689, 56772, 57059, 57763, 57792, 58123, 58141, 58265, 58448, 58507, 58691, 58704, 59082, 59085, 59343, 59509, 59783, 60050, 60410, 60419, 60501, 60552, 60594, 60634, 61123, 61326, 61397, 61501, 61572, 61625, 61808, 61867, 62020, 62862, 62930, 63123, 63174, 63340, 63563, 63634, 63638, 63830, 64012, 64136, 64190, 64194, 64281, 64319, 64374, 64378, 64726, 65484, 65486, 65581, 65636, 65745, 66185, 66340, 66452, 66506, 66718, 66812, 66842, 66903, 66967, 66996, 67025, 67084, 67429, 67796, 67877, 68057, 68449, 68497, 68581, 68764, 68815, 68959, 69083, 69124, 69215, 69266, 69308, 69325, 69725, 69739, 69835, 70000, 70429, 70440, 70707, 70745, 70807, 70931, 71067, 71114, 71125, 71158, 71173, 71251, 71386, 71449, 71826, 71827, 71951, 72035, 72093, 72134, 72193, 72296, 72453, 72544, 72637, 72736, 72739, 73000, 73003, 73117, 73241, 73363, 73378, 73424, 73440, 73454, 73483, 73502, 73547, 73685, 73707, 73744, 73818, 73942, 74067, 74085, 74125, 74158, 74184, 74209, 74251, 74392, 74445, 74451, 74536, 74569, 74629, 74660, 74752, 74753, 74811, 74843]


if d == 26261:
    quit(OK, "Это лучший ответ\n", score=100)
elif d == 27730:
    quit(WA, f"Этот ответ правильный, но не лучший. Ваш ответ {d}, а в лучшем ответе наименьшая прочность помоста равна 26261.\n", score=60)
elif d == 30551:
    quit(WA, f"Этот ответ правильный, но не лучший. Ваш ответ {d}, а в лучшем ответе наименьшая прочность помоста равна 26261.\n", score=50)
elif d == 30758:
    quit(WA, f"Этот ответ правильный, но не лучший. Ваш ответ {d}, а в лучшем ответе наименьшая прочность помоста равна 26261.\n", score=40)
elif d == 30777:
    quit(WA, f"Этот ответ правильный, но не лучший. Ваш ответ {d}, а в лучшем ответе наименьшая прочность помоста равна 26261.\n", score=30)
elif d == 31013:
    quit(WA, f"Этот ответ правильный, но не лучший. Ваш ответ {d}, а в лучшем ответе наименьшая прочность помоста равна 26261.\n", score=20)
elif d == 32910:
    quit(WA, f"Этот ответ правильный, но не лучший. Ваш ответ {d}, а в лучшем ответе наименьшая прочность помоста равна 26261.\n", score=10)
elif d in D:
    quit(WA, f"Этот ответ правильный, но не лучший. Ваш ответ {d}, а в лучшем ответе наименьшая прочность помоста равна 26261.\n", score=5)
elif d < max(D):
    quit(CF, "Ошибка проверяющей программы, ответ нужного качества, но не оценён")
else:
    quit(OK, f"Этот ответ неправильный.\n", score=0)

